@@ -6,6 +6,7 @@
 #' @section Aesthetics: 
 #' \Sexpr[results=rd,stage=build]{ggtern:::rd_aesthetics("geom", "InterpolateTern")}
 #' @inheritParams geom_confidence_tern
+#' @inheritParams geom_density_tern
 #' @inheritParams ggplot2::geom_smooth
 #' @inheritParams ggplot2::geom_point
 #' @inheritParams ggplot2::geom_path
@@ -24,8 +25,7 @@
 geom_interpolate_tern <- function( mapping = NULL, data = NULL, stat = "InterpolateTern", position = "identity", 
                                    ...,
                                    lineend = "butt",linejoin = "round", linemitre = 1,
-                                   na.rm = FALSE, show.legend = NA,inherit.aes = TRUE, 
-                                   method='auto', formula=value~poly(x,y,degree=1)) {
+                                   na.rm = FALSE, show.legend = NA,inherit.aes = TRUE) {
   layer(
     data        = data,
     mapping     = mapping,
@@ -39,8 +39,6 @@ geom_interpolate_tern <- function( mapping = NULL, data = NULL, stat = "Interpol
       linejoin    = linejoin,
       linemitre   = linemitre,
       na.rm       = na.rm,
-      formula     = formula,
-      method      = method,
       ...
     )
   )
