@@ -8,6 +8,8 @@
                          'is.layer','is.facet','is.Coord','GeomSegment',
                          '.element_tree','el_def','combine_elements','aes_to_scale',
                          'is.Coord','is.facet','is.layer','make_labels',
+                         'aes_to_scale',
+                         'scales_add_missing','scales_list','scales_transform_df','scales_map_df','scales_train_df',
                          'predictdf','contour_lines','check_required_aesthetics','snake_class',
                          'ggname','camelize')
 .functions.gridExtra  = c('latticeGrob')
