@@ -1,5 +1,3 @@
-.theme_showtitles <- function(show=TRUE){theme(axis.tern.showtitles=show)}
-
 #' Show or Hide the Axis (Apex) Titles
 #' 
 #' Convenience functions to SHOW or HIDE the apex labels.
@@ -12,7 +10,6 @@
 #'  ggtern(data=Feldspar,aes(An,Ab,Or)) + geom_point() + theme_bw() + theme_hidetitles()
 NULL
 
-
 #' \code{theme_showtitles} is a function that apends to the current theme a flag to switch ON the apex titles.
 #' @rdname theme_showtitles
 #' @export
@@ -26,4 +23,8 @@ theme_hidetitles <- function(){.theme_showtitles(FALSE)}
 
 #' @rdname theme_showtitles
 #' @export
-theme_notitles <- theme_hidetitles
\ No newline at end of file
+theme_notitles <- theme_hidetitles
+
+#Internals
+.theme_showtitles <- function(show=TRUE){theme(tern.axis.title.show=show)}
+
